@@ -1323,7 +1323,7 @@ class MainApp:
     def load_settings(self):
         self.HOMEDIR = os.path.expanduser('~')
         
-        self.SAVEDIR = os.path.join(self.HOMEDIR, '.outlaw_solitaire')
+        self.SAVEDIR = os.path.join(self.HOMEDIR, '.outlawsolitaire')
         if os.path.exists(self.SAVEDIR):
             pass
         else:
@@ -1641,4 +1641,4 @@ class MainApp:
                 self.containers.handle_events(event)
 
 if __name__ == '__main__':
-    pass                
\ No newline at end of file
+    pass                
